#![no_std]
#![no_main]

extern crate panic_halt;

use core::{arch::asm, ptr::{write, read}};

use riscv_rt::entry;

mod eth;

// use `main` as the entry point of this application
// `main` is not allowed to return
#[entry]
fn main() -> ! {
    eth::init();

    let blink_period = if eth::is_wishbone_correct() {
        10_000_000
    } else {
        500_000
    };

    loop {
        //eth::tranmsit();
        write_led(0);
        busy_wait(blink_period);
        write_led(1);
        busy_wait(blink_period);
    }
}

fn busy_wait(num_nops: u32) {
    for _ in 0..num_nops {
        unsafe {
            asm!("nop");
        }
    }
}

fn write_led(val: u32) {
    unsafe { write_reg(0x0100200, val); }
}

unsafe fn write_reg<T>(addr: u32, value: T) {
    write(addr as *mut T, value);
}

unsafe fn read_reg<T>(addr: u32) -> T {
    return read(addr as *mut T);
}
